# The tests fail due to task queue overflows in iurt,
# rather than any particular code failure, so they're disabled for now
%bcond_with tests

# We do not have Fedora infrastructure,
# so this aspect of Koschei is disabled
%bcond_with fedora_infra

Name:           koschei
Version:        2.4.0
Release:        %mkrel 3
Summary:        Continuous integration for packages built with Koji and Copr
Group:          System/Servers
License:        GPLv2+
URL:            https://github.com/msimacek/%{name}
Source0:        https://github.com/msimacek/%{name}/archive/%{version}/%{name}-%{version}.tar.gz

# Upstream patches
Patch0001:      0001-Port-to-new-hawkey.patch

# Mageia specific patches
# We don't have js-jquery packaged, so revert to using online copy
Patch1000:      koschei-2.4.0-mga-Revert-Use-local-JQuery.patch

BuildArch:      noarch

# For systemd macro definitions
BuildRequires:  systemd-devel

BuildRequires:  python3-devel
BuildRequires:  python3-setuptools

%if %{with tests}
BuildRequires:  postgresql-server
BuildRequires:  python3-mock
BuildRequires:  python3-nose
BuildRequires:  python3-vcrpy
%endif

BuildRequires:  python3-sqlalchemy
BuildRequires:  python3-koji
BuildRequires:  python3-hawkey
BuildRequires:  python3-librepo
BuildRequires:  python3-rpm
#BuildRequires:  python3-fedmsg-core
BuildRequires:  python3-psycopg2
BuildRequires:  python3-flask
BuildRequires:  python3-flask-sqlalchemy
BuildRequires:  python3-flask-wtf
BuildRequires:  python3-wtforms
BuildRequires:  python3-humanize >= 0.5.1
BuildRequires:  python3-jinja2
BuildRequires:  python3-dogpile-cache
BuildRequires:  python3-copr
BuildRequires:  python3-requests


%description
Service tracking dependency changes and rebuilding packages whose
dependencies change too much. It uses Koji scratch builds to do the rebuilds and
provides a web interface to the results.


%package common
Summary:        Actual python code for koschei backend and frontend
Group:          System/Servers
Requires:       python3-sqlalchemy
Requires:       python3-psycopg2
Requires:       python3-rpm
Requires(pre):  shadow-utils

%description common
%{summary}.


%package admin
Summary:        Administration script and DB migrations for koschei
Group:          System/Servers
Requires:       %{name}-common = %{version}-%{release}
Requires:       python3-alembic
Requires:       postgresql


%description admin
%{summary}.

%package frontend
Summary:        Web frontend for koschei using mod_wsgi
Group:          System/Servers
Requires:       %{name}-common = %{version}-%{release}
Requires:       python3-flask
Requires:       python3-flask-sqlalchemy
Requires:       python3-flask-wtf
Requires:       python3-wtforms
Requires:       python3-humanize >= 0.5.1
Requires:       python3-jinja2
Requires:       apache-python3-mod_wsgi
Requires:       apache

%description frontend
%{summary}.

%package backend
Summary:        Koschei backend services
Group:          System/Servers
Requires:       %{name}-common = %{version}-%{release}
Requires:       python3-koji
Requires:       python3-hawkey
Requires:       python3-librepo
Requires:       python3-dogpile-cache
Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd

%description backend
%{summary}.

%if %{with fedora_infra}
%package common-fedora
Summary:        Fedora-specific Koschei plugins (common parts of backend and frontend)
Group:          System/Servers
Requires:       %{name}-common = %{version}-%{release}
Requires:       python3-dogpile-cache

%description common-fedora
%{summary}.

%package frontend-fedora
Summary:        Fedora-specific Koschei frontend plugins
Group:          System/Servers
Requires:       %{name}-frontend = %{version}-%{release}
Requires:       %{name}-common-fedora = %{version}-%{release}
Requires:       python3-requests

%description frontend-fedora
%{summary}.

%package backend-fedora
Summary:        Fedora-specific Koschei backend plugins
Group:          System/Servers
Requires:       %{name}-backend = %{version}-%{release}
Requires:       %{name}-common-fedora = %{version}-%{release}
Requires:       python3-fedmsg-core
Requires:       python3-fedmsg-meta-fedora-infrastructure

Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd

%description backend-fedora
%{summary}.
%endif

%package common-copr
Summary:        Koschei plugin for user rebuilds in Copr (common part)
Group:          System/Servers
Requires:       %{name}-common = %{version}-%{release}

%description common-copr
%{summary}.

%package backend-copr
Summary:        Koschei plugin for user rebuilds in Copr (backend part)
Group:          System/Servers
Requires:       %{name}-backend = %{version}-%{release}
Requires:       %{name}-common-copr = %{version}-%{release}
Requires:       python3-copr

%description backend-copr
%{summary}.

%package frontend-copr
Summary:        Koschei plugin for user rebuilds in Copr (frontend part)
Group:          System/Servers
Requires:       %{name}-frontend = %{version}-%{release}
Requires:       %{name}-common-copr = %{version}-%{release}

%description frontend-copr
%{summary}.


%prep
%autosetup -p1

sed 's|@CACHEDIR@|%{_localstatedir}/cache/%{name}|g
     s|@DATADIR@|%{_datadir}/%{name}|g
     s|@VERSION@|%{version}-%{release}|g
     s|@CONFDIR@|%{_sysconfdir}/%{name}|g
     s|@STATEDIR@|%{_sharedstatedir}/%{name}|g' config.cfg.template > config.cfg

%build
%py3_build

PYTHONPATH=".:${PYTHONPATH}" %{__python3} aux/gen-bash-completion.py >koschei-admin.bash

%install
%py3_install

mkdir -p %{buildroot}%{_bindir}
mkdir -p %{buildroot}%{_datadir}/%{name}
mkdir -p %{buildroot}%{_sysconfdir}/%{name}
mkdir -p %{buildroot}%{_sysconfdir}/httpd/conf.d

cp -p config-backend.cfg %{buildroot}%{_sysconfdir}/%{name}/config-backend.cfg
cp -p config-frontend.cfg %{buildroot}%{_sysconfdir}/%{name}/config-frontend.cfg
cp -p config-admin.cfg %{buildroot}%{_sysconfdir}/%{name}/config-admin.cfg
cp -p config.cfg %{buildroot}%{_datadir}/koschei/
cp -p *.sql %{buildroot}%{_datadir}/koschei/

install -dm 755 %{buildroot}%{_unitdir}
for unit in systemd/*; do
    install -pm 644 $unit %{buildroot}%{_unitdir}/
done

install -pm 755 admin.py %{buildroot}%{_bindir}/%{name}-admin

install -dm 755 %{buildroot}%{_localstatedir}/cache/%{name}/repodata
install -dm 755 %{buildroot}%{_sharedstatedir}/%{name}

cp -pr templates %{buildroot}%{_datadir}/%{name}/

cp -pr alembic/ alembic.ini %{buildroot}%{_datadir}/%{name}/
cp -pr static %{buildroot}%{_datadir}/%{name}/
cp -p %{name}.wsgi %{buildroot}%{_datadir}/%{name}/
cp -p httpd.conf %{buildroot}%{_sysconfdir}/httpd/conf.d/%{name}.conf

install -dm 755 %{buildroot}%{_libexecdir}/%{name}
ln -s %{__python3} %{buildroot}%{_libexecdir}/%{name}/koschei-scheduler
ln -s %{__python3} %{buildroot}%{_libexecdir}/%{name}/koschei-watcher
ln -s %{__python3} %{buildroot}%{_libexecdir}/%{name}/koschei-polling
ln -s %{__python3} %{buildroot}%{_libexecdir}/%{name}/koschei-build-resolver
ln -s %{__python3} %{buildroot}%{_libexecdir}/%{name}/koschei-repo-resolver
ln -s %{__python3} %{buildroot}%{_libexecdir}/%{name}/koschei-copr-resolver
ln -s %{__python3} %{buildroot}%{_libexecdir}/%{name}/koschei-copr-scheduler

install -dm 755 %{buildroot}%{_sysconfdir}/bash_completion.d/
install -p -m 644 koschei-admin.bash %{buildroot}%{_sysconfdir}/bash_completion.d/

%if ! %{with fedora_infra}
rm -rfv %{buildroot}%{python3_sitelib}/*/plugins/fedmsg_plugin
rm -rfv %{buildroot}%{python3_sitelib}/*/plugins/pagure_plugin

rm -fv %{buildroot}%{_libexecdir}/%{name}/*watcher*
rm -fv %{buildroot}%{_unitdir}/*watcher*
%endif


%if %{with tests}
%check
. aux/set-env.sh
pg_init
pg_start
trap pg_stop 0
%{__python3} setup.py test
%endif

%pre common
getent group %{name} >/dev/null || groupadd -r %{name}
# services and koschei-admin script is supposed to be run as this user
getent passwd %{name} >/dev/null || \
    useradd -r -g %{name} -d %{_localstatedir}/cache/%{name} -s /bin/sh \
    -c "Runs %{name} services" %{name}
exit 0

%post backend
%systemd_post %{name}-scheduler.service
%systemd_post %{name}-polling.service
%systemd_post %{name}-build-resolver.service
%systemd_post %{name}-repo-resolver.service

%preun backend
%systemd_preun %{name}-scheduler.service
%systemd_preun %{name}-polling.service
%systemd_preun %{name}-build-resolver.service
%systemd_preun %{name}-repo-resolver.service

%if %{with fedora_infra}
%post backend-fedora
%systemd_post %{name}-watcher.service

%preun backend-fedora
%systemd_preun %{name}-watcher.service
%endif

%post backend-copr
%systemd_post %{name}-copr-resolver.service
%systemd_post %{name}-copr-scheduler.service

%preun backend-copr
%systemd_preun %{name}-copr-resolver.service
%systemd_preun %{name}-copr-scheduler.service

%files common
%license LICENSE.txt
%{python3_sitelib}/*
%exclude %{python3_sitelib}/koschei/admin.py
%exclude %{python3_sitelib}/koschei/frontend
%exclude %{python3_sitelib}/koschei/backend
%exclude %{python3_sitelib}/koschei/plugins/*/
%dir %{python3_sitelib}/koschei/plugins
%{python3_sitelib}/koschei/plugins/__init__.*
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/config.cfg
%attr(755, %{name}, %{name}) %{_localstatedir}/cache/%{name}
%dir %{_sysconfdir}/%{name}
%attr(755, %{name}, %{name}) %dir %{_sharedstatedir}/%{name}

%files admin
%{_bindir}/%{name}-admin
%dir %{_libexecdir}/%{name}
%{python3_sitelib}/koschei/admin.py
%{_datadir}/%{name}/alembic/
%{_datadir}/%{name}/*.sql
%{_datadir}/%{name}/alembic.ini
%{_sysconfdir}/bash_completion.d
%config(noreplace) %{_sysconfdir}/%{name}/config-admin.cfg

%files frontend
%config(noreplace) %{_sysconfdir}/httpd/conf.d/%{name}.conf
%config(noreplace) %{_sysconfdir}/%{name}/config-frontend.cfg
%{_datadir}/%{name}/static
%{_datadir}/%{name}/templates
%{_datadir}/%{name}/%{name}.wsgi
%{python3_sitelib}/*/frontend

%files backend
%config(noreplace) %{_sysconfdir}/%{name}/config-backend.cfg
%dir %{_libexecdir}/%{name}
%{_libexecdir}/%{name}/koschei-scheduler
%{_libexecdir}/%{name}/koschei-polling
%{_libexecdir}/%{name}/koschei-build-resolver
%{_libexecdir}/%{name}/koschei-repo-resolver
%{_unitdir}/koschei-scheduler.service
%{_unitdir}/koschei-polling.service
%{_unitdir}/koschei-build-resolver.service
%{_unitdir}/koschei-repo-resolver.service
%{python3_sitelib}/*/backend
%{python3_sitelib}/*/plugins/repo_regen_plugin

%if %{with fedora_infra}
%files common-fedora
%{python3_sitelib}/*/plugins/fedmsg_plugin
%{python3_sitelib}/*/plugins/pagure_plugin
%exclude %{python3_sitelib}/*/plugins/*/backend*
%exclude %{python3_sitelib}/*/plugins/*/frontend*

%files frontend-fedora
%{python3_sitelib}/*/plugins/pagure_plugin/frontend*

%files backend-fedora
%{_libexecdir}/%{name}/koschei-watcher
%{_unitdir}/koschei-watcher.service
%{python3_sitelib}/*/plugins/fedmsg_plugin/backend*
%endif

%files common-copr
%{python3_sitelib}/*/plugins/copr_plugin
%exclude %{python3_sitelib}/*/plugins/*/backend*
%exclude %{python3_sitelib}/*/plugins/*/frontend*

%files frontend-copr
%{python3_sitelib}/*/plugins/copr_plugin/frontend*

%files backend-copr
%{_libexecdir}/%{name}/koschei-copr-resolver
%{_libexecdir}/%{name}/koschei-copr-scheduler
%{_unitdir}/koschei-copr-resolver.service
%{_unitdir}/koschei-copr-scheduler.service
%{python3_sitelib}/*/plugins/copr_plugin/backend*



%changelog
* Sun Feb 16 2020 umeabot <umeabot> 2.4.0-3.mga8
+ Revision: 1536672
- Mageia 8 Mass Rebuild

* Mon Oct 21 2019 daviddavid <daviddavid> 2.4.0-2.mga8
+ Revision: 1455021
- rebuild for python3.8

* Tue Jan 15 2019 ngompa <ngompa> 2.4.0-1.mga7
+ Revision: 1357073
- Disable test run during package build for now
- Rebase to 2.4.0
- Switch to Python 3
- Backport patch from upstream for new hawkey
- Refresh patch for using online jQuery
+ umeabot <umeabot>
- Mageia 7 Mass Rebuild
- Mageia 7 Mass Rebuild

* Sun May 14 2017 ngompa <ngompa> 1.10.0-1.mga6
+ Revision: 1101046
- Upgrade to 1.10.0

* Mon Dec 12 2016 ngompa <ngompa> 1.8.2-1.mga6
+ Revision: 1074311
- Upgrade to 1.8.2

* Sun Oct 16 2016 tv <tv> 1.7-3.mga6
+ Revision: 1061151
- BR systemd-devel for macro definition (mga#12027)

* Sat May 28 2016 ngompa <ngompa> 1.7-2.mga6
+ Revision: 1019169
- imported package koschei


* Sat May 28 2016 Neal Gompa <ngompa13@gmail.com> - 1.7-2
- Port to Mageia
- Disable Fedora infrastructure specific bits for now

* Fri May 20 2016 Michael Simacek <msimacek@redhat.com> 1.7-1
- Update to upstream version 1.7

* Thu May 12 2016 Michael Simacek <msimacek@redhat.com> 1.6.1-1
- Fix registering real buids via watcher

* Thu Apr 21 2016 Michael Simacek <msimacek@redhat.com> 1.6-1
- Update to upstream release 1.6

* Fri Apr 08 2016 Michael Simacek <msimacek@redhat.com> 1.5-2
- Build with tito

* Thu Apr 07 2016 Michael Simacek <msimacek@redhat.com> - 1.5-1
- Update to upstream version 1.5

* Fri Mar 11 2016 Mikolaj Izdebski <mizdebsk@redhat.com> - 1.4.3-1
- Update to upstream version 1.4.3

* Mon Mar  7 2016 Mikolaj Izdebski <mizdebsk@redhat.com> - 1.4.2-1
- Update to upstream version 1.4.2

* Wed Mar 02 2016 Michael Simacek <msimacek@redhat.com> - 1.4.1-1
- Update to upstream release 1.4.1

* Fri Feb 26 2016 Mikolaj Izdebski <mizdebsk@redhat.com> - 1.4-1
- Update to upstream version 1.4

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Fri Oct  2 2015 Mikolaj Izdebski <mizdebsk@redhat.com> - 1.3-1
- Update to upstream version 1.3

* Wed Sep 23 2015 Michael Simacek <msimacek@redhat.com> - 1.2-2
- Backport fix for group editing permissions

* Tue Sep 22 2015 Mikolaj Izdebski <mizdebsk@redhat.com> - 1.2-1
- Update to upstream version 1.2

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Tue Jun 02 2015 Michael Simacek <msimacek@redhat.com> - 1.1-1
- Update to version 1.1

* Wed May 20 2015 Mikolaj Izdebski <mizdebsk@redhat.com> - 1.0-1
- Update to upstream version 1.0

* Fri Mar 27 2015 Mikolaj Izdebski <mizdebsk@redhat.com> - 0.2-2
- Add workaround for RPM bug #646523

* Thu Mar 12 2015 Michael Simacek <msimacek@redhat.com> - 0.2-1
- Update to version 0.2

* Mon Sep 01 2014 Michael Simacek <msimacek@redhat.com> - 0.1-2
- Fixed BR python-devel -> python2-devel
- Fixed changelog format
- Added noreplace to httpd config
- Replaced name occurences with macro

* Fri Jun 13 2014 Michael Simacek <msimacek@redhat.com> - 0.1-1
- Initial version
